@@ -1,5 +1,6 @@
 import json
 import re
+from collections import OrderedDict
 from django.conf import settings
 from django.db import connection, transaction
 from django.http import HttpResponse
@@ -35,7 +36,7 @@ def look(request):
     else:
       cursor = connection.cursor()
       cursor.execute(command)
-      data = [dict(zip([column[0] for column in cursor.description], [str(cell) for cell in row])) for row in cursor.fetchall()]
+      data = [OrderedDict(zip([column[0] for column in cursor.description], [unicode(cell) for cell in row])) for row in cursor.fetchall()]
   except Exception as e:
     error = e.message
   finally:
